﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using static System.Windows.Forms.VisualStyles.VisualStyleElement;

namespace _3BranchingAlgorithms
{
    public partial class BranchingAlgorithms : Form
    {
        /// <summary>
        /// Метод ColculateF
        /// выполняет определённую функцию в зависимости от выбора
        /// </summary>
        /// <param name="x">переменная используемая функцией</param>
        /// <returns>возращает значение функции</returns>
        public double ColculateF(double x)
        {
            double f = 0;
            if (rbHyperbola.Checked)
                f = (e * x) - e - Math.Pow(x, 2);
            if (rbX2.Checked)
                f = Math.Pow(x, 2);
            if (rbEX.Checked)
                f = Math.Pow(e, x);
            return f;
        }
        /// <summary>
        /// Метод BranchingAlgorithmsSolution
        /// Реализует разветвляющиеся алгоритмы
        /// </summary>
        /// <param name="x">Переменная из tbX</param>
        /// <param name="q">Переменная из tbQ</param>
        /// <param name="k">Переменная из tbK</param>
        /// <returns>Возвращает значение уравнения</returns>
        public double BranchingAlgorithmsSolution(double x, double q, double k)
        {
            if (Math.Abs(x * k) > 10) u = Math.Log10(ColculateF(Math.Pow(x, 2))) + Math.Abs(k);
            if (Math.Abs(x * k) < 10) u = Math.Pow(3.14, ColculateF(x) + q);
            if (Math.Abs(x * k) == 10) u = ColculateF(x) - k;
            return u;
        }
        double x, q, k, u;
        const double e = 2.7;

        /// <summary>
        /// Метод BranchingAlgorithms
        /// Инициализирует компоненты
        /// </summary>
        public BranchingAlgorithms()
        {
            InitializeComponent();
        }
        /// <summary>
        /// Метод btnStart_Click:
        /// проверка функции, присваивание переменным значения полей,
        /// вывод отета и обращение к методу BranchingAlgorithmsSolution
        /// </summary>
        /// <param name="sender">Объект, вызвавший событие</param>
        /// <param name="e">Передает объект, относящийся к обрабатываемому событию</param>
        private void btnStart_Click(object sender, EventArgs e)
        {
            if (!rbHyperbola.Checked && !rbX2.Checked && !rbEX.Checked)
            {
                MessageBox.Show("Выберите функцию");
                return;
            }
            try
            {
                k = Convert.ToDouble(tbK.Text);
                q = Convert.ToDouble(tbQ.Text);
                x = Convert.ToDouble(tbX.Text);
            }
            catch
            {
                tbK.Text = "Ошибка";
                tbQ.Text = "Ошибка";
                tbX.Text = "Ошибка";
                return;
            }
            tbConclusion.Text = "Результаты работы программы ст. Романова" + Environment.NewLine;
            tbConclusion.Text += $"При X = {x}" + Environment.NewLine;
            tbConclusion.Text += $"При Q = {q}" + Environment.NewLine;
            tbConclusion.Text += $"При K = {k}" + Environment.NewLine;
            BranchingAlgorithmsSolution(x, q, u);   
            tbConclusion.Text += $"U = {u}" + Environment.NewLine;
        }
        /// <summary>
        /// Метод btnClear_Click
        /// очищает значения полей
        /// </summary>
        /// <param name="sender">Объект, вызвавший событие</param>
        /// <param name="e">Передает объект, относящийся к обрабатываемому событию</param>
        private void btnClear_Click(object sender, EventArgs e)
        {
            tbX.Text = "0";
            tbQ.Text = "0";
            tbK.Text = "0";
            tbConclusion.Text = "";
        }
    }
}
